@@ -165,7 +165,7 @@ class QCticAPI:
             err_msg = "[{}] {}".format(err.get("name"), err.get("description"))
             raise QCticAPIError(err_msg)
 
-    async def get_job(self, job_id):
+    async def get_job(self, job_id, lean=False):
         """Retrieves a single Job from the API.
 
         Args:
@@ -175,10 +175,12 @@ class QCticAPI:
             dict: Dict that conforms to the ``JobSchema`` schema.
         """
 
-        req = self._request(
-            url=self._build_url("/jobs/{}".format(job_id)),
-            method="GET")
+        url = self._build_url("/jobs/{}".format(job_id))
 
+        if lean:
+            url = url_concat(url, {"lean": True})
+
+        req = self._request(url=url, method="GET")
         _logger.debug(_format_req(req))
         res = await self._fetch(req)
         job_dict = json_decode(res.body)
